@@ -2,10 +2,11 @@ package Text::Markup::Creole;
 
 use 5.8.1;
 use strict;
+use warnings;
 use File::BOM qw(open_bom);
 use Text::WikiCreole;
 
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 sub parser {
     my ($file, $encoding, $opts) = @_;
@@ -14,7 +15,9 @@ sub parser {
     my $html = creole_parse(<$fh>);
     return unless $html =~ /\S/;
     utf8::encode($html);
+    return $html if $opts->{raw};
     return qq{<html>
+<head>
 <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
 </head>
 <body>
@@ -35,6 +38,7 @@ Text::Markup::Creole - Creole parser for Text::Markup
 =head1 Synopsis
 
   my $html = Text::Markup->new->parse(file => 'file.creole');
+  my $raw  = Text::Markup->new->parse(file => 'file.creole', raw => 1);
 
 =head1 Description
 
@@ -53,13 +57,17 @@ It recognizes files with the following extensions as Markdown:
 
 =back
 
+Normally this module returns the output wrapped in a minimal HTML document
+skeleton. If you would like the raw output without the skeleton, you can pass
+the C<raw> option to C<parse>.
+
 =head1 Author
 
 Lucas Kanashiro <kanashiro.duarte@gmail.com>
 
 =head1 Copyright and License
 
-Copyright (c) 2011-2014 Lucas Kanashiro. Some Rights Reserved.
+Copyright (c) 2011-2019 Lucas Kanashiro. Some Rights Reserved.
 
 This module is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
