@@ -2,10 +2,11 @@ package Text::Markup::Textile;
 
 use 5.8.1;
 use strict;
+use warnings;
 use File::BOM qw(open_bom);
 use Text::Textile '2.10';
 
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 sub parser {
     my ($file, $encoding, $opts) = @_;
@@ -20,7 +21,9 @@ sub parser {
     my $html = $textile->process(<$fh>);
     return unless $html =~ /\S/;
     utf8::encode($html);
+    return $html if $opts->{raw};
     return qq{<html>
+<head>
 <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
 </head>
 <body>
@@ -41,6 +44,7 @@ Text::Markup::Textile - Textile parser for Text::Markup
 =head1 Synopsis
 
   my $html = Text::Markup->new->parse(file => 'README.textile');
+  my $raw  = Text::Markup->new->parse(file => 'README.textile', raw => 1);
 
 =head1 Description
 
@@ -59,13 +63,17 @@ It recognizes files with the following extension as Textile:
 
 =back
 
+Normally this module returns the output wrapped in a minimal HTML document
+skeleton. If you would like the raw output without the skeleton, you can pass
+the C<raw> option to C<parse>.
+
 =head1 Author
 
 David E. Wheeler <david@justatheory.com>
 
 =head1 Copyright and License
 
-Copyright (c) 2011-2014 David E. Wheeler. Some Rights Reserved.
+Copyright (c) 2011-2019 David E. Wheeler. Some Rights Reserved.
 
 This module is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
